@@ -1,5 +1,5 @@
 ## color_fun_1.R | unikn
-## spds | uni.kn | 2023 07 28
+## spds | uni.kn | 2023 09 21
 ## --------------------------
 
 ## Define color-related functions 
@@ -95,12 +95,12 @@ usecol <- function(pal = pal_unikn,
                    use_names = FALSE,  # should colors be returned as a named vector?
                    use_col_ramp = FALSE) {
   
-  ## 0. Handle NA input: ----
+  ## Handle NA input: ----
   
   if (all(is.na(pal))) { return(NA) }
   
   
-  ## 1. Parse input: ---- 
+  ## Parse input: ---- 
   
   parenv <- parent.frame()
   
@@ -110,21 +110,20 @@ usecol <- function(pal = pal_unikn,
   pal_inp <- tryCatch(
     
     {
-      suppressWarnings(parse_pal(pal = pal))  # suppress any warnings in parsing. 
-      
+      suppressWarnings(parse_pal(pal = pal))  # suppress warnings in parsing. 
     },
     
-    # Handle any errors by checking further:
+    # Handle errors by checking further:
     error = function(e) {
       
-      # seecol always triggers this part
+      # Get object name in parenv (always triggered by seecol):
       pal <- deparse(substitute(expr = pal, env = parenv))
       
       # Remove slashes and quotes:
       pal <- gsub("\\\\", "", pal)
-      pal <- gsub("\"", "", pal)
+      pal <- gsub("\"",   "", pal)
       
-      # Reparse with new input: 
+      # Recursion: Re-parse with new input pal: 
       parse_pal(pal = pal)
       
     }
@@ -189,7 +188,6 @@ usecol <- function(pal = pal_unikn,
       
       # Define sets of known palettes:
       set1 <- pal_name %in% c("pal_peach",
-                              "pal_peach",
                               "pal_petrol",
                               "pal_pinky",
                               "pal_karpfenblau",
@@ -216,7 +214,7 @@ usecol <- function(pal = pal_unikn,
                         
                         # Set 1: -----
                         switch(n,
-                               pal[4],
+                               pal[4], # main color
                                pal[c(4, 2)],
                                pal[c(5, 3, 1)],
                                pal[c(5, 4, 2, 1)],
@@ -224,7 +222,7 @@ usecol <- function(pal = pal_unikn,
                         
                         # Set 2: -----
                         switch(n,
-                               pal[3],
+                               pal[3], # main color
                                pal[c(4, 2)],
                                pal[c(5, 3, 1)],
                                pal[c(5, 4, 2, 1)],
@@ -337,8 +335,7 @@ usecol <- function(pal = pal_unikn,
   } # if ( !use_col_ramp ).
   
   
-  # If no defined palette is used or the number exceeds 
-  # the number of colors use colorRamp: ----- 
+  # No defined pal or excess N of colors: Use colorRamp: ----- 
   
   if (!pal_def) {
     
@@ -349,7 +346,7 @@ usecol <- function(pal = pal_unikn,
       
     } else {
       
-      # use the colorRamp (removing all names): 
+      # use colorRamp (removing all names): 
       out_col <- grDevices::colorRampPalette(pal_inp)(n) 
       
     } # if (n == length(pal_inp)).
@@ -359,10 +356,10 @@ usecol <- function(pal = pal_unikn,
   
   # Process out_col: ------ 
   
-  # Name the palette (as comment attribute): ---- 
+  # - Name the palette (as comment attribute): ---- 
   comment(out_col) <- ifelse(pal_def, pal_name, "custom")
   
-  # Get color names (if no names are given): ---- 
+  # - Get color names (if no names are given): ---- 
   if ( use_names & all(is.null(names(out_col))) ) {
     
     # # (A) Combine kn_names with color() names:
@@ -399,10 +396,10 @@ usecol <- function(pal = pal_unikn,
     
   } # if (no names in out_col).
   
-  # Remove names if required (default): ---- 
+  # - Remove names if required (default): ---- 
   if ( !use_names ) { out_col <- unname(out_col) }
   
-  # Handle alpha: ----
+  # - Handle alpha: ----
   if ( !(is.null(alpha) | is.na(alpha))) { 
     
     cmnt <- comment(out_col)  # save palette name
@@ -411,7 +408,7 @@ usecol <- function(pal = pal_unikn,
     
   }
   
-  # Remove visual duplicates: ---- 
+  # - Remove visual duplicates: ---- 
   if ( distinct ){
     
     out_col <- col_distinct(out_col, use_alpha = FALSE) # (based on HEX values, but ignoring transparency)
@@ -419,6 +416,7 @@ usecol <- function(pal = pal_unikn,
   }
   
   
+  
   # Output: ---- 
   
   return(out_col)
@@ -495,7 +493,7 @@ usecol <- function(pal = pal_unikn,
 #'   \item \code{"pref_all"}: All preferred uni.kn colors and their gradients. 
 #'   
 #'   \item \code{"add"}: Additional/contributed color palettes 
-#'   (migrated to the \bold{unicol} package).
+#'   (deprecated, as additional color palettes were migrated to the \bold{unicol} R package).
 #' }
 #' 
 #' \code{seecol} does also recognize keywords (e.g., \code{"all_unikn"}) or 
@@ -531,6 +529,9 @@ usecol <- function(pal = pal_unikn,
 #' @param grid Show grid in the color plot?  
 #' Default: \code{grid = TRUE}. 
 #' 
+#' @param scale_x Scale color shapes (when comparing multiple palettes) to a fixed total width?
+#' Default: \code{scale_x = FALSE}.
+#' 
 #' @param main Main plot title (as a character string). 
 #' Default: \code{main = NA} creates a default title.
 #' 
@@ -562,6 +563,9 @@ usecol <- function(pal = pal_unikn,
 #' seecol(c(rev(pal_seeblau), "white", pal_pinky))  # combine color palettes and color names
 #' seecol(c("black", "firebrick", "gold"))          # combine color names
 #' 
+#' # Scale a set of color palettes to a fixed width:
+#' seecol(scale_x = TRUE)
+#' 
 #' # Using n to reduce or extend color palettes:
 #' seecol(n =  3)  # viewing reduced ranges of all palettes
 #' seecol(n = 12)  # viewing extended ranges of all palettes
@@ -579,13 +583,13 @@ usecol <- function(pal = pal_unikn,
 #' pal_mpg <- c("#007367", "white", "#D0D3D4")  # mixing hex values and color names
 #' names(pal_mpg) <- c("mpg green", "mpg white", "mpg grey")  # color names
 #' 
-#' pal_bdg <- usecol(c(Bordeaux, "gold"), n = 10)  # using usecol
+#' pal_bdg <- usecol(c(Bordeaux, "gold"), n = 5)  # using usecol
 #' 
 #' # Viewing extended color palette: 
 #' seecol(pal_mpg, n = 9, main = "Custom color palette of the Max Planck Society")
 #' 
 #' # Comparing (and labeling) custom color palettes: 
-#' seecol(list(pal_mpg, pal_bdg, pal_unikn), n = 7,
+#' seecol(list(pal_mpg, pal_bdg, pal_unikn), scale_x = TRUE,
 #'        pal_names = c("Max Planck", "Bordeaux-Gold", "Uni Konstanz"), 
 #'        main = "Comparing and labeling custom color palettes")
 #' 
@@ -626,6 +630,7 @@ seecol <- function(pal = "unikn_all",  # which palette?
                    col_brd = NULL,     # border color of the boxes
                    lwd_brd = NULL,     # line width of box borders
                    grid = TRUE,        # show grid? 
+                   scale_x = FALSE,    # scale color shapes (when comparing multiple palettes) to a fixed total width?
                    main = NA,          # main plot title (using the default 'main = NA' constructs a default title)
                    sub = NULL,         # plot subtitle (on bottom)
                    title = NULL,       # Deprecated: plot title (replaced by main)
@@ -653,6 +658,11 @@ seecol <- function(pal = "unikn_all",  # which palette?
     main <- title  # Note: Any prior settings of main is lost.
   }
   
+  if ((length(pal) == 1) && (pal == "add")){
+    message("As the 'add' keyword is deprecated, I will use 'all' instead.\nAdditional color palettes were migrated to the 'unicol' R package.")
+    pal <- "all"
+  }
+  
   # Constants/parameters: ---- 
   
   op <- par(no.readonly = TRUE)  # save original plotting settings.
@@ -748,7 +758,15 @@ seecol <- function(pal = "unikn_all",  # which palette?
           
         } else { # use default names: 
           
-          names(pal_tmp)[ix_cp] <- paste0("pal_", which(ix_cp))
+          # (a) use pal_nr:
+          # names(pal_tmp)[ix_cp] <- paste0("pal_", which(ix_cp))
+          
+          # (b) use element names of the pal list argument:
+          # list_element_names <- paste0(as.character(substitute(pal)))[-1]
+          list_element_names <- as.character(substitute(pal))[-1]
+          # print(list_element_names)  # 4debugging
+          
+          names(pal_tmp) <- list_element_names  # +++ here now +++ 
           
         }
       }
@@ -804,8 +822,8 @@ seecol <- function(pal = "unikn_all",  # which palette?
   
   # 2. Plotting parameters: -------- 
   
-  distance <- 0   # set distance of boxes?
-  xlen <- 1       # set x length of color boxes.
+  distance <- 0   # distance of boxes
+  xlen <- 1       # x length of color boxes
   
   # Get maximum number of colors:
   max_ncol <- max(unlist(lapply(pal_tmp, FUN = length)))
@@ -831,6 +849,11 @@ seecol <- function(pal = "unikn_all",  # which palette?
     
     # print(length(pal_tmp))  # 4debugging
     
+    # list_element_names <- paste0(as.character(substitute(pal)))[-1]
+    # print(list_element_names)
+    # # OR: 
+    # rlang::enexpr(pal)  
+    
     # Set margins:
     if ((is.null(sub) == FALSE) && (is.na(sub) == FALSE) && (sub != "") ){
       par(mar = c(5.2, 6, 3, 1))  # enable subtitle at bottom (line 5)
@@ -877,9 +900,26 @@ seecol <- function(pal = "unikn_all",  # which palette?
     # Add the color vectors:
     # if (is.null(lwd_brd)) { lwd_brd <- 0 } # set default lwd_brd
     
+    # # For testing:
+    # plot(x = 0,
+    #      type = "n",
+    #      xlim = xlim, ylim = ylim,
+    #      xaxt = "n", yaxt = "n",  # hide axes.
+    #      xlab = "", ylab = "",
+    #      main = main,
+    #      sub = sub,
+    #      bty = "n"
+    #      # ...  # other graphical parameters
+    # )
+    
     apply(pal_mat, MARGIN = 1, FUN = function(row) {
-      plot_col(x = row[[1]], ypos = row[2], plot.new = FALSE, 
-               ylen = ylen, col_brd = col_brd, lwd = lwd_brd)
+      
+      # If color swaps are to be scaled, determine length:
+      if (scale_x) { xlen <- max_ncol/length(row[[1]]) }  
+      
+      # Plot color shapes:
+      plot_col(x = row[[1]], ypos = row[2], plot.new = FALSE,
+               ylen = ylen, col_brd = col_brd, xlen = xlen, lwd = lwd_brd)
     })
     
     # Label pal names:
@@ -896,11 +936,15 @@ seecol <- function(pal = "unikn_all",  # which palette?
     wdth_ind <- sum(strwidth(txt_ind, cex = cex_ind))
     pos_ind <- seq(0.5, (max_ncol - 0.5), by = 1)
     
+    # Recursively decrease the width (to fitting, even number):
     while (wdth_ind > xlim[2]) {
       
-      txt_ind <- txt_ind[seq(1, length(txt_ind), by = 2)]  # only show every 2nd index.
-      pos_ind <- pos_ind[seq(1, length(pos_ind), by = 2)]
-      wdth_ind <- sum(strwidth(txt_ind, cex = cex_ind))  # is the width small enough?
+      # TODO: Issue of displayed indices: they are adapted to width and for even numbers starting from 1
+      #       creates uneven ends of the sequence.
+      #       Requires a function with fixed start and end, interpolating between the two.
+      txt_ind  <- txt_ind[seq(1, length(txt_ind), by = 2)]  # only show every 2nd index.
+      pos_ind  <- pos_ind[seq(1, length(pos_ind), by = 2)]
+      wdth_ind <- sum(strwidth(txt_ind, cex = cex_ind))  # is the width of the string [..] small enough?
       
     } # while end. 
     
@@ -908,13 +952,19 @@ seecol <- function(pal = "unikn_all",  # which palette?
     cex_ixs <- .80
     yix <- -0.02 * length(pal_tmp)  # dynamic positioning of indices. 
     
-    text(x = pos_ind, y = yix, labels = txt_ind, pos = 1, xpd = TRUE,
-         cex = cex_ixs, col = grey(0, 2/3))
+    # Add labels only, when colors are not scaled to width and if there are less than 30 colors:
+    # TODO: Determine maximum number!
+    if (!scale_x & (max_ncol < 100)) {
+      
+      text(x = pos_ind, y = yix, labels = txt_ind, pos = 1, xpd = TRUE,
+           cex = cex_ixs, col = grey(0, 2/3))
+      
+    }
+    
     
   } else {  # if length(pal_tmp) list is NOT > 1:
     
     
-    
     # 3-2. Plot a detailed view of 1 palette: -------  
     
     names(pal_tmp) <- NULL  # remove first order names! 
@@ -1026,8 +1076,11 @@ seecol <- function(pal = "unikn_all",  # which palette?
              # ...  # other graphical parameters
     )
     
-    # Plot circles: ---- 
-    circle_len <- ifelse(((xlim[2] / 10) < .70), (xlim[2] / 10), .70)
+    # Plot circles: ----
+    
+    # WAS: circle_len <- ifelse(((xlim[2] / 10) < .70), (xlim[2] / 10), .70)    
+    # Bigger circle shapes:
+    circle_len <- ifelse(((xlim[2] / 10) < .70), (xlim[2] / 8), .75)
     
     plot_col(x = pal_tmp, ypos = y_circ, shape = "circle", xlen = circle_len, plot.new = FALSE, col_brd = col_brd, lwd = lwd_brd#,
              # ...  # other graphical parameters
@@ -1181,7 +1234,7 @@ seecol <- function(pal = "unikn_all",  # which palette?
 # par(op)
 
 
-# all_colors(): Combine all unikn color palettes with default R colors() ------
+# all_colors(): Combine all colors from unikn palettes with default R colors() ------
 
 #' Provide all unikn colors and base R colors 
 #' 
@@ -1207,67 +1260,12 @@ all_colors <- function(distinct = TRUE){
   
   # 1. All colors (of unikn package): ---- 
   
-  # +++ here now +++:
-  
-  # unikn_pkg_colors <- usecol(c("black", "white",
-  #                              # Local uni.kn colors:
-  #                              pal_grau, pal_bordeaux, pal_petrol, pal_peach, 
-  #                              pal_seeblau, pal_pinky, pal_seegruen, pal_karpfenblau, 
-  #                              pal_signal, 
-  #                              pal_unikn,  # contains 4 "seegrau" variants of "grey"
-  #                              # Added/contributed color palettes:
-  #                              caltech_pal_1, caltech_pal_2, caltech_pal_3, 
-  #                              eth_pal_1, eth_pal_2, eth_pal_3, 
-  #                              fu_pal_0, fu_pal_1, fu_pal_2, fu_pal_3, 
-  #                              hu_pal_1, hu_pal_2, 
-  #                              lmu_pal_1, lmu_pal_2, lmu_pal_3, 
-  #                              mpg_pal, 
-  #                              uni_bonn_1, uni_bonn_2, 
-  #                              uni_goettingen_1, uni_goettingen_2, uni_goettingen_3, 
-  #                              uni_freiburg_0, uni_freiburg_1, uni_freiburg_2, 
-  #                              uni_freiburg_br, uni_freiburg_blue, uni_freiburg_info,
-  #                              uni_hamburg_1, uni_hamburg_2, 
-  #                              uni_jena_1, uni_jena_2, 
-  #                              uni_kiel_1, uni_kiel_2, 
-  #                              uni_koeln_1, uni_koeln_2, 
-  #                              # uni_konstanz_1, uni_konstanz_2,  # duplicates of pal_ (above).
-  #                              uni_mannheim_1, uni_mannheim_2, 
-  #                              uni_princeton_0, uni_princeton_1, uni_princeton_2,
-  #                              uni_regensburg_1, uni_regensburg_2, uni_regensburg_3,
-  #                              uni_ulm_1, uni_ulm_2, 
-  #                              rpi_pal_1, rpi_pal_2, rpi_pal_3,
-  #                              rptu_pal 
-  # ), 
-  # use_names = TRUE)
-  
   unikn_pkg_colors <- usecol(c("black", "white",
                                # Local uni.kn colors:
                                pal_grau, pal_bordeaux, pal_petrol, pal_peach, 
                                pal_seeblau, pal_pinky, pal_seegruen, pal_karpfenblau, 
                                pal_signal, 
                                pal_unikn # contains 4 "seegrau" variants of "grey"
-                               # # Added/contributed color palettes:
-                               # caltech_pal_1, caltech_pal_2, caltech_pal_3, 
-                               # eth_pal_1, eth_pal_2, eth_pal_3, 
-                               # fu_pal_0, fu_pal_1, fu_pal_2, fu_pal_3, 
-                               # hu_pal_1, hu_pal_2, 
-                               # lmu_pal_1, lmu_pal_2, lmu_pal_3, 
-                               # mpg_pal, 
-                               # uni_bonn_1, uni_bonn_2, 
-                               # uni_goettingen_1, uni_goettingen_2, uni_goettingen_3, 
-                               # uni_freiburg_0, uni_freiburg_1, uni_freiburg_2, 
-                               # uni_freiburg_br, uni_freiburg_blue, uni_freiburg_info,
-                               # uni_hamburg_1, uni_hamburg_2, 
-                               # uni_jena_1, uni_jena_2, 
-                               # uni_kiel_1, uni_kiel_2, 
-                               # uni_koeln_1, uni_koeln_2, 
-                               # # uni_konstanz_1, uni_konstanz_2,  # duplicates of pal_ (above).
-                               # uni_mannheim_1, uni_mannheim_2, 
-                               # uni_princeton_0, uni_princeton_1, uni_princeton_2,
-                               # uni_regensburg_1, uni_regensburg_2, uni_regensburg_3,
-                               # uni_ulm_1, uni_ulm_2, 
-                               # rpi_pal_1, rpi_pal_2, rpi_pal_3,
-                               # rptu_pal 
   ), 
   use_names = TRUE)
   
@@ -1309,8 +1307,8 @@ all_colors <- function(distinct = TRUE){
 # length(all_colors(distinct = TRUE))   #  756 [on 2023-07-13]
 # length(all_colors(distinct = FALSE))  # 1031 [on 2023-07-13]
 
-# length(all_colors(distinct = TRUE))   #  545 [on 2023-07-28]
-# length(all_colors(distinct = FALSE))  #  713 [on 2023-07-28]
+# length(all_colors(distinct = TRUE))   #  545 [on 2023-08-20]
+# length(all_colors(distinct = FALSE))  #  713 [on 2023-08-20]
 
 # grepal("see", all_colors())     # finds unikn colors (and matching colors())
 # grepal("gruen", all_colors())   # finds unikn and added colors
@@ -1324,15 +1322,14 @@ all_colors <- function(distinct = TRUE){
 # grepal("orange", all_colors())  # finds Caltech and Princeton orange colors
 # 
 # simcol(Petrol, all_colors())
-# simcol(mpg_pal[1], all_colors())
-# simcol(uni_princeton_0[1], all_colors())
+
 
 
 ## ToDo: ------
 
 # - seecol(): Compare 
-# seecol(eth_pal_3) # showing only 6-digit HEX values, with 
-# seecol(eth_pal_3[3:7]) # showing full HEX values (8 digits) for transparent colors
+# seecol(unicol::eth_3) # showing only 6-digit HEX values for transparent colors, with 
+# seecol(unicol::eth_3[3:7]) # showing full HEX values (8 digits) for transparent colors
 
 # - usecol(): $comment attribute "custom" prevents output from being a vector
 
