@@ -1,6 +1,6 @@
 ## plot_demo.R | unikn
-## spds | uni.kn | 2023 03 06
-## ---------------------------
+## spds | uni.kn | 2024 02 14
+## --------------------------
 
 ## Demo functions for color palettes.
 
@@ -583,7 +583,7 @@ plot_table <- function(pal, col_par = NULL, alpha = 1,
 
 
 
-# 5. plot_scatter(): A plot of points ------ 
+# 5. plot_scatter(): A plot of dots / points ------ 
 
 # Note: ... passed to plot().
 
@@ -649,6 +649,62 @@ plot_scatter <- function(pal, col_par = NULL, alpha = 2/3,
   
   df <- data.frame(x = x, y = y)
   
+  
+  # Modify df (to add 3d-perspective effect): ----
+  
+  perspective_3d <- FALSE # TRUE
+  
+  if (perspective_3d){
+    
+    # Reduce viewing level (horizon):
+    # df$y  <- .25 * df$y
+    # y_max <- max(df$y)
+    
+    # Re-arrange rows of df:
+    df <- df[order(y, decreasing = TRUE), ]  # lower y-values on top
+    
+    # Reduce size of points with larger y values:
+    max_cex_reduce <- cex/2
+    
+    max_y <- max(df$y)
+    min_y <- min(df$y)
+    y_pos <- df$y > 1     # logical index of values to reduce
+    cex   <- rep(cex, n)  # as vector
+    
+    # cex[y_pos] <- cex[y_pos] / (.999 * df$y[y_pos])  # shrink object cex by y-value
+    cex[y_pos] <- cex[y_pos] - max_cex_reduce * df$y[y_pos]/(max_y - min_y)
+    
+    # x-distortion: Reduce range of x-values depending on y-values:
+    
+    # shift points with high y-values to right:
+    max_shift_right <- 2
+    max_shift_left  <- 2
+    
+    max_x <- max(df$x)
+    min_x <- min(df$x)    
+    max_y <- max(df$y)
+    min_y <- min(df$y)
+    
+    old_x_range <- (max_x - min_x)
+    new_x_range <- (max_x - max_shift_left) - (min_x + max_shift_right)
+    
+    scale_y <- df$y / (max_y - min_y)
+    scale_x <- df$x / old_x_range
+    
+    new_x <- (min_x + max_shift_right) + scale_x * new_x_range
+    
+    df$x <- new_x # * scale_y
+    
+    
+    # + (max_shift_right * df$y / (max_y - min_y)) 
+    #             - (max_shift_left  * df$y / (max_y - min_y))   # +++ here now +++
+    
+    # remove border:
+    # col_par <- NA
+    
+  } 
+  
+  
   # Main plot: ---- 
   
   plot(#0, 0, type = "n",  # (a) empty plot
@@ -701,6 +757,8 @@ plot_scatter <- function(pal, col_par = NULL, alpha = 2/3,
 # x <- plot_scatter(pal_unikn_pref, alpha = 2/3, seed = 101)
 # x
 
+# 3d-effect:
+# plot_scatter(pal_unikn, n = 1000, alpha = 1, cex = 3, col_par = "black")
 
 
 
@@ -864,6 +922,7 @@ demopal <- function(pal = pal_unikn, type = NA, pal_name = NULL, ...){
 
 ## ToDo: --------
 
+# - Add 3d-perspective effects (e.g., to scatterplot).
 # - Add more plot types.
 
 ## eof. ----------
\ No newline at end of file
