@@ -1,8 +1,8 @@
 ## util.R | unikn
-## spds | uni.kn |  2022 12 30
+## spds | uni.kn |  2024 04 16
 ## ---------------------------
 
-# General utility functions (mostly for internal use, not exported).
+# General utility functions (mostly for internal use and not exported).
 
 
 # Generic utility functions: --------  
@@ -20,7 +20,7 @@ add_quotes <- function(x) {
 
 # - monotonic: Check if a vector is monotonically increasing ------ 
 
-monotonic <-function(v) {
+monotonic <- function(v) {
   
   mono <- NA
   
@@ -56,14 +56,16 @@ set_seed <- function(seed = NULL){
 
 
 
-# - url_unikn: Format an URL the unikn way ------ 
+# - url_unikn: Format an URL the uni.kn way ------ 
 
 #' \code{url_unikn} formats an URL the uni.kn way 
 #' 
 #' \code{url_unikn} removes various patterns (e.g., 
 #' \code{"http", "https", "://", "www."}) from the 
 #' front of a given URL and returns the remaining character string 
-#' with a figure dash prefix.
+#' with an n-dash (Unicode \code{\\u2013}) prefix, 
+#' rather than the former figure dash (\code{\\u2012}) prefix 
+#' (as the latter created issues on Fedora Linux systems). 
 #' 
 #' @param url The url to be written (as copied from a web browser).
 #' 
@@ -106,7 +108,7 @@ url_unikn <- function(url = "https://www.uni-konstanz.de/"){
   # "\u2212": minus 
   
   # Add dash to front:
-  prefix <- "\u2012"
+  prefix <- "\u2013" # WAS: "\u2012"
   out <- paste0(prefix, " ", out)  # prefix + 1 space  
   
   return(out)
@@ -120,6 +122,7 @@ url_unikn <- function(url = "https://www.uni-konstanz.de/"){
 
 
 
+
 # - kill_all: Clean/empty current environment ------
 
 kill_all <- function(){
